Direction

Trait Direction 

pub trait Direction {
    type Message;

    // Required method
    fn decode(frame: Frame) -> Result<Self::Message>;
}
Decoder direction. The same byte tag has different meanings in each direction.

Required Associated Types

type Message

Typed message family produced for this direction.

Required Methods

fn decode(frame: Frame) -> Result<Self::Message>

Errors

Returns an error when the tag is unknown or its body is malformed.

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors