pub enum BackendBatchProjectionError {
Cardinality {
expected: usize,
actual: usize,
},
IllegalSource,
IllegalReplacement,
DifferentSpan,
}Expand description
Validation failure for an ordered one-to-one backend replacement span.
Variants
Cardinality
Replacement cardinality differed from the held span.
Fields
IllegalSource
A held source was not attributable at this pipeline position.
IllegalReplacement
A proposed replacement was illegal or not reconstructable.
DifferentSpan
Replacements would consume a different protocol span than the sources.