pub enum CancelError<ConnectorError> {
Connector(ConnectorError),
Protocol(Error),
}Expand description
Failure while sending a one-shot PostgreSQL cancellation packet.
Variants
Connector(ConnectorError)
The configured connector could not open the cancellation transport.
Protocol(Error)
The key could not be encoded or the raw packet could not be written.