FrontendForwarding

Enum FrontendForwarding 

pub enum FrontendForwarding {
    Forwarded(FrontendMessage),
    Suppressed(FrontendMessage),
    LocallyHandled(FrontendMessage),
}
Observable result of processing one client-originated message.

Variants



Forwarded(FrontendMessage)

The message was sent to PostgreSQL.



Suppressed(FrontendMessage)

The message was consumed without being sent.



LocallyHandled(FrontendMessage)

The request was admitted as local and its responses were emitted or queued.

Implementations

Source

impl FrontendForwarding

pub fn into_message(self) -> FrontendMessage

Returns the owned client message represented by this outcome.