Module grammar

Module grammar 

Generated PostgreSQL grammars and differential-test runtime FSMs.

Each generated role module embeds its railroad diagram directly in its rustdoc landing page. Open a module such as frontend or backend to review the grammar alongside its generated transition API.

Modules

authentication
Generated authentication protocol grammar.
backend
Generated backend protocol grammar.
frontend
Generated frontend protocol grammar.
pre_startup
Generated pre_startup protocol grammar.
server_authentication
Generated server_authentication protocol grammar.
server_pre_startup
Generated server_pre_startup protocol grammar.