AuthCleartextExternalTransitionMessage

Struct AuthCleartextExternalTransitionMessage 

pub struct AuthCleartextExternalTransitionMessage(/* private fields */);
Validated wire message for one legal Auth transition.

Implementations

Source

impl AuthCleartextExternalTransitionMessage

pub const fn as_wire(&self) -> &BackendMessage

Borrows the validated wire message.

pub fn into_wire(self) -> BackendMessage

Returns the validated wire message.

pub fn try_map_wire( self, map: impl FnOnce(BackendMessage) -> BackendMessage, ) -> Result<Self, BackendMessage>

Mutates or replaces the wire value while preserving this transition variant.

Errors

Returns the replacement when it no longer denotes this phase transition.