pub struct BuildingDescribeInternalTransitionMessage(/* private fields */);Expand description
Validated wire message for one legal Building transition.
Implementations
Sourceimpl BuildingDescribeInternalTransitionMessage
impl BuildingDescribeInternalTransitionMessage
Sourcepub const fn as_wire(&self) -> &FrontendMessage
pub const fn as_wire(&self) -> &FrontendMessage
Borrows the validated wire message.
Sourcepub fn into_wire(self) -> FrontendMessage
pub fn into_wire(self) -> FrontendMessage
Returns the validated wire message.
Sourcepub fn try_map_wire(
self,
map: impl FnOnce(FrontendMessage) -> FrontendMessage,
) -> Result<Self, FrontendMessage>
pub fn try_map_wire( self, map: impl FnOnce(FrontendMessage) -> FrontendMessage, ) -> Result<Self, FrontendMessage>
Mutates or replaces the wire value while preserving this transition variant.
Errors
Returns the replacement when it no longer denotes this phase transition.