pub struct FunctionCallingErrorExternalTransitionMessage(/* private fields */);Expand description
Validated wire message for one legal FunctionCalling transition.
Implementations
Sourceimpl FunctionCallingErrorExternalTransitionMessage
impl FunctionCallingErrorExternalTransitionMessage
Sourcepub const fn as_wire(&self) -> &BackendMessage
pub const fn as_wire(&self) -> &BackendMessage
Borrows the validated wire message.
Sourcepub fn into_wire(self) -> BackendMessage
pub fn into_wire(self) -> BackendMessage
Returns the validated wire message.
Sourcepub fn try_map_wire(
self,
map: impl FnOnce(BackendMessage) -> BackendMessage,
) -> Result<Self, BackendMessage>
pub fn try_map_wire( self, map: impl FnOnce(BackendMessage) -> BackendMessage, ) -> Result<Self, BackendMessage>
Mutates or replaces the wire value while preserving this transition variant.
Errors
Returns the replacement when it no longer denotes this phase transition.