pub struct PreStartupStartupInternalTransitionMessage(/* private fields */);Expand description
Validated wire message for one legal PreStartup transition.
Implementations
Sourceimpl PreStartupStartupInternalTransitionMessage
impl PreStartupStartupInternalTransitionMessage
Sourcepub const fn as_wire(&self) -> &PreStartupMessage
pub const fn as_wire(&self) -> &PreStartupMessage
Borrows the validated wire message.
Sourcepub fn into_wire(self) -> PreStartupMessage
pub fn into_wire(self) -> PreStartupMessage
Returns the validated wire message.
Sourcepub fn try_map_wire(
self,
map: impl FnOnce(PreStartupMessage) -> PreStartupMessage,
) -> Result<Self, PreStartupMessage>
pub fn try_map_wire( self, map: impl FnOnce(PreStartupMessage) -> PreStartupMessage, ) -> Result<Self, PreStartupMessage>
Mutates or replaces the wire value while preserving this transition variant.
Errors
Returns the replacement when it no longer denotes this phase transition.