TypedSession

Struct TypedSession 

pub struct TypedSession<Transport, Phase, Cleanliness = ()> { /* private fields */ }
Transport-carrying typestate for this protocol role.

Implementations

Source

impl<Transport, Cleanliness> TypedSession<Transport, PreStartup, Cleanliness>

pub const fn with_transport(transport: Transport) -> Self

Attaches transport to a session in the initial phase.

Source

impl<Transport, Phase, Cleanliness> TypedSession<Transport, Phase, Cleanliness>

pub fn map_transport<Next>( self, map: impl FnOnce(Transport) -> Next, ) -> TypedSession<Next, Phase, Cleanliness>

Replaces the transport representation without changing protocol indices.

pub fn into_transport(self) -> Transport

Deliberately leaves the generated typestate API and returns its transport.

Source

impl<Transport, Cleanliness> TypedSession<Transport, PreStartup, Cleanliness>

pub fn ssl_request( self, ) -> TypedSession<Transport, AwaitingSslReply, Cleanliness>

Applies ssl_request and enters AwaitingSslReply.

pub fn gss_request( self, ) -> TypedSession<Transport, AwaitingGssReply, Cleanliness>

Applies gss_request and enters AwaitingGssReply.

pub fn cancel<Output, Error>( self, payload: (u32, Bytes), handle: impl FnOnce(&mut Transport, (u32, Bytes)) -> Result<Output, Error>, ) -> Result<(TypedSession<Transport, Terminated, Cleanliness>, Output), (Self, Error)>

Handles the payload for cancel; success enters Terminated and failure returns the unchanged session.

pub fn startup<Output, Error>( self, payload: StartupMessage, handle: impl FnOnce(&mut Transport, StartupMessage) -> Result<Output, Error>, ) -> Result<(TypedSession<Transport, Auth, Cleanliness>, Output), (Self, Error)>

Handles the payload for startup; success enters Auth and failure returns the unchanged session.

Source

impl<Transport, Cleanliness> TypedSession<Transport, AwaitingSslReply, Cleanliness>

pub fn accept(self) -> TypedSession<Transport, TlsHandshake, Cleanliness>

Applies accept and enters TlsHandshake.

pub fn reject(self) -> TypedSession<Transport, PreStartup, Cleanliness>

Applies reject and enters PreStartup.

pub fn legacy_error(self) -> TypedSession<Transport, Terminated, Cleanliness>

Applies legacy_error and enters Terminated.

Source

impl<Transport, Cleanliness> TypedSession<Transport, AwaitingGssReply, Cleanliness>

pub fn accept(self) -> TypedSession<Transport, GssHandshake, Cleanliness>

Applies accept and enters GssHandshake.

pub fn reject(self) -> TypedSession<Transport, PreStartup, Cleanliness>

Applies reject and enters PreStartup.

pub fn legacy_error(self) -> TypedSession<Transport, Terminated, Cleanliness>

Applies legacy_error and enters Terminated.

Source

impl<Transport, Cleanliness> TypedSession<Transport, TlsHandshake, Cleanliness>

pub fn complete(self) -> TypedSession<Transport, PreStartup, Cleanliness>

Applies complete and enters PreStartup.

Source

impl<Transport, Cleanliness> TypedSession<Transport, GssHandshake, Cleanliness>

pub fn complete(self) -> TypedSession<Transport, PreStartup, Cleanliness>

Applies complete and enters PreStartup.