pub struct SslDecisionRejectInternalTransitionMessage(/* private fields */);Expand description
Validated wire message for one legal SslDecision transition.
Implementations
Sourceimpl SslDecisionRejectInternalTransitionMessage
impl SslDecisionRejectInternalTransitionMessage
Sourcepub const fn as_wire(&self) -> &EncryptionReply
pub const fn as_wire(&self) -> &EncryptionReply
Borrows the validated wire message.
Sourcepub fn into_wire(self) -> EncryptionReply
pub fn into_wire(self) -> EncryptionReply
Returns the validated wire message.
Sourcepub fn try_map_wire(
self,
map: impl FnOnce(EncryptionReply) -> EncryptionReply,
) -> Result<Self, EncryptionReply>
pub fn try_map_wire( self, map: impl FnOnce(EncryptionReply) -> EncryptionReply, ) -> Result<Self, EncryptionReply>
Mutates or replaces the wire value while preserving this transition variant.
Errors
Returns the replacement when it no longer denotes this phase transition.