pub enum WireAdapterError<Error, Wire> {
Middleware(Error),
IllegalReplacement(Wire),
}Expand description
Failure from direction-wide middleware adapted to a typed phase.
Variants
Middleware(Error)
The wrapped middleware rejected the message according to its policy.
IllegalReplacement(Wire)
The wrapped middleware returned a wire message illegal in the typed phase.