ReconstructableMessage

Trait ReconstructableMessage 

pub trait ReconstructableMessage {
    // Required method
    fn is_reconstructable(&self) -> bool;
}
A protocol message which can verify that it has a valid wire representation.

Required Methods

fn is_reconstructable(&self) -> bool

Reports whether this typed value can be encoded on the wire.

Dyn Compatibility

This trait is dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors