TypedOutboundPhase

Trait TypedOutboundPhase 

pub trait TypedOutboundPhase<Role, Wire> {
    type ProtocolPhase;
    type Message: AsRef<Wire> + TryFrom<Wire, Error = Wire> + Into<Wire>;
}
Associates a connection typestate with messages its local role may send.

Unlike TypedPhase, which describes peer-selected input, this trait indexes the generated internal message set used before a locally generated value is encoded and sent.

Required Associated Types

type ProtocolPhase

Generated grammar phase corresponding to the connection typestate.

type Message: AsRef<Wire> + TryFrom<Wire, Error = Wire> + Into<Wire>

Opaque set of locally generated messages legal in this phase.

Dyn Compatibility

This trait is dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors

Source

impl TypedOutboundPhase<ClientRole, FrontendMessage> for BoundBuilding

Source

impl TypedOutboundPhase<ClientRole, FrontendMessage> for Building

Source

impl TypedOutboundPhase<ClientRole, FrontendMessage> for CopyBoth

Source

impl TypedOutboundPhase<ClientRole, FrontendMessage> for CopyBothServerDone

Source

impl TypedOutboundPhase<ClientRole, FrontendMessage> for CopyIn

Source

impl TypedOutboundPhase<ClientRole, FrontendMessage> for PasswordResponse

Source

impl TypedOutboundPhase<ClientRole, FrontendMessage> for Ready

Source

impl TypedOutboundPhase<ClientRole, FrontendMessage> for SaslChallenge

Source

impl TypedOutboundPhase<ClientRole, FrontendMessage> for SaslInitial

Source

impl TypedOutboundPhase<ClientRole, FrontendMessage> for TokenResponse

Source

impl TypedOutboundPhase<ClientRole, PreStartupMessage> for PreStartup

Source

impl TypedOutboundPhase<ServerRole, BackendMessage> for ServerAuth

Source

impl TypedOutboundPhase<ServerRole, BackendMessage> for ServerAuthPolicy

Source

impl TypedOutboundPhase<ServerRole, BackendMessage> for ServerAuthResponse

Source

impl TypedOutboundPhase<ServerRole, BackendMessage> for ServerBind

Source

impl TypedOutboundPhase<ServerRole, BackendMessage> for ServerBuilding

Source

impl TypedOutboundPhase<ServerRole, BackendMessage> for ServerClose

Source

impl TypedOutboundPhase<ServerRole, BackendMessage> for ServerCopyBoth<CopyExtended, BothClientDone>

Source

impl TypedOutboundPhase<ServerRole, BackendMessage> for ServerCopyBoth<CopyExtended, BothDone>

Source

impl TypedOutboundPhase<ServerRole, BackendMessage> for ServerCopyBoth<CopyExtended, BothOpen>

Source

impl TypedOutboundPhase<ServerRole, BackendMessage> for ServerCopyBoth<CopyExtended, BothServerDone>

Source

impl TypedOutboundPhase<ServerRole, BackendMessage> for ServerCopyBoth<CopySimple, BothClientDone>

Source

impl TypedOutboundPhase<ServerRole, BackendMessage> for ServerCopyBoth<CopySimple, BothDone>

Source

impl TypedOutboundPhase<ServerRole, BackendMessage> for ServerCopyBoth<CopySimple, BothOpen>

Source

impl TypedOutboundPhase<ServerRole, BackendMessage> for ServerCopyBoth<CopySimple, BothServerDone>

Source

impl TypedOutboundPhase<ServerRole, BackendMessage> for ServerCopyBothFailed<CopyExtended>

Source

impl TypedOutboundPhase<ServerRole, BackendMessage> for ServerCopyBothFailed<CopySimple>

Source

impl TypedOutboundPhase<ServerRole, BackendMessage> for ServerCopyIn<CopyExtended>

Source

impl TypedOutboundPhase<ServerRole, BackendMessage> for ServerCopyIn<CopySimple>

Source

impl TypedOutboundPhase<ServerRole, BackendMessage> for ServerCopyInDone<CopyExtended>

Source

impl TypedOutboundPhase<ServerRole, BackendMessage> for ServerCopyInDone<CopySimple>

Source

impl TypedOutboundPhase<ServerRole, BackendMessage> for ServerCopyInFailed<CopyExtended>

Source

impl TypedOutboundPhase<ServerRole, BackendMessage> for ServerCopyInFailed<CopySimple>

Source

impl TypedOutboundPhase<ServerRole, BackendMessage> for ServerCopyOut<CopyExtended>

Source

impl TypedOutboundPhase<ServerRole, BackendMessage> for ServerCopyOut<CopySimple>

Source

impl TypedOutboundPhase<ServerRole, BackendMessage> for ServerCopyOutDone<CopyExtended>

Source

impl TypedOutboundPhase<ServerRole, BackendMessage> for ServerCopyOutDone<CopySimple>

Source

impl TypedOutboundPhase<ServerRole, BackendMessage> for ServerDescribe

Source

impl TypedOutboundPhase<ServerRole, BackendMessage> for ServerExecute

Source

impl TypedOutboundPhase<ServerRole, BackendMessage> for ServerExtendedError

Source

impl TypedOutboundPhase<ServerRole, BackendMessage> for ServerFunctionCall

Source

impl TypedOutboundPhase<ServerRole, BackendMessage> for ServerFunctionCallDone

Source

impl TypedOutboundPhase<ServerRole, BackendMessage> for ServerFunctionCallError

Source

impl TypedOutboundPhase<ServerRole, BackendMessage> for ServerParse

Source

impl TypedOutboundPhase<ServerRole, BackendMessage> for ServerPassword

Source

impl TypedOutboundPhase<ServerRole, BackendMessage> for ServerSasl

Source

impl TypedOutboundPhase<ServerRole, BackendMessage> for ServerSaslInitial

Source

impl TypedOutboundPhase<ServerRole, BackendMessage> for ServerSaslResponse

Source

impl TypedOutboundPhase<ServerRole, BackendMessage> for ServerSimpleError

Source

impl TypedOutboundPhase<ServerRole, BackendMessage> for ServerSimpleQuery

Source

impl TypedOutboundPhase<ServerRole, BackendMessage> for ServerStartupReady

Source

impl TypedOutboundPhase<ServerRole, BackendMessage> for ServerStartupRejected

Source

impl TypedOutboundPhase<ServerRole, BackendMessage> for ServerSync

Source

impl TypedOutboundPhase<ServerRole, EncryptionReply> for ServerGssDecision

Source

impl TypedOutboundPhase<ServerRole, EncryptionReply> for ServerSslDecision