pub enum BackendPipelineWireAdapterError<Error> {
Middleware(Error),
Illegal(BackendMessage),
}Expand description
Failure from backend wire middleware adapted to typed pipeline dispatch.
Variants
Middleware(Error)
The wrapped middleware rejected a message.
Illegal(BackendMessage)
The wrapped middleware returned a message illegal in the selected phase.