ResourceScope

Struct ResourceScope 

pub struct ResourceScope<'id> { /* private fields */ }
Connection-local statement and portal namespaces.

Implementations

Source

impl<'id> ResourceScope<'id>

pub fn simple_query_boundary(&mut self)

Records a simple-query boundary, which destroys the unnamed statement.

pub fn transaction_ended(&mut self)

Records transaction end, which destroys the unnamed portal.

pub fn prepare( &mut self, client_name: Bytes, upstream_name: Bytes, query: Bytes, parameter_types: Vec<u32>, ) -> Result<(PreparedStatement<'id>, Parse), ResourceError>

Allocates a statement token and reconstructable upstream Parse message.

Errors

Rejects duplicate upstream statement names.

pub fn bind( &mut self, statement: &PreparedStatement<'id>, client_name: Bytes, upstream_name: Bytes, parameter_formats: Vec<i16>, parameters: Vec<Option<Bytes>>, result_formats: Vec<i16>, ) -> Result<(Portal<'id>, Bind), ResourceError>

Binds a branded statement into a rewritten portal namespace.

Errors

Rejects statements not present in this scope and duplicate portal names.

pub fn close_statement( &mut self, statement: PreparedStatement<'id>, ) -> Result<Close, ResourceError>

Closes a statement and removes its upstream name from this scope.

Errors

Rejects a token which has already been closed.

pub fn close_portal( &mut self, portal: Portal<'id>, ) -> Result<Close, ResourceError>

Closes a portal and removes its upstream name from this scope.

Errors

Rejects a token which has already been closed.

pub fn statement(&self, client_name: &[u8]) -> Option<PreparedStatement<'id>>

Resolves a client-visible statement name to its branded upstream token.

pub fn portal(&self, client_name: &[u8]) -> Option<Portal<'id>>

Resolves a client-visible portal name to its branded upstream token.