Module server_auth

Module server_auth 

Server-role authentication typestates for proxy-side client termination.

Structs

SaslInitialResponse
A decoded SASL initial response selected by the client.

Enums

ServerAuth
The proxy is selecting how to authenticate its client.
ServerAuthResponse
A GSS, SSPI, or Kerberos response token is expected.
ServerPassword
A password response is expected from the client.
ServerProtocolOffer
Result of validating a client’s requested protocol version.
ServerSasl
A recursive SASL response exchange is in progress.
ServerSaslInitial
A SASL initial response is expected from the client.
ServerStartupReady
Authentication succeeded and startup metadata may be sent before readiness.
ServerStartupRejected
The client’s startup protocol version must be rejected.
ServerStartupValidated
The client’s startup protocol version is supported.

Type Aliases

PasswordProjection
Projection of a valid password body or the unchanged server-password state.
SaslInitialProjection
Projection of a valid SASL initial response or the unchanged initial state.
ServerProjection
A rejected frontend message paired with the unchanged authentication state.