pub enum ServerProtocolOffer<S, C> {
Supported {
conn: Conn<S, ServerStartupValidated, C>,
message: StartupMessage,
negotiate_to: Option<ProtocolVersion>,
},
Rejected {
conn: Conn<S, ServerStartupRejected, C>,
message: StartupMessage,
},
}Expand description
Result of validating a client’s requested protocol version.
Variants
Supported
The major version is supported, with optional minor-version negotiation.
Fields

conn: Conn<S, ServerStartupValidated, C>Connection authorised to begin authentication.

message: StartupMessageInspected startup message.

negotiate_to: Option<ProtocolVersion>Highest supported version to advertise when the requested minor is newer.
Rejected
The major protocol version is unsupported.
Fields

conn: Conn<S, ServerStartupRejected, C>Connection authorised only to send an error and terminate.

message: StartupMessageRejected startup message.