pub enum SimpleTransition<S, C> {
Continue(Conn<S, SimpleQuery, C>, SessionItem),
CopyIn(Conn<S, CopyIn, C>, CopyResponse),
CopyOut(Conn<S, CopyOut, C>, CopyResponse),
CopyBoth(Conn<S, CopyBoth, C>, CopyResponse),
Ready(ReadyState<S, C>),
Error(Conn<S, Draining, C>, ErrorResponse),
}Expand description
Backend branch available while a simple query is active.
Variants
Continue(Conn<S, SimpleQuery, C>, SessionItem)
A result item was consumed and more results may follow.
CopyIn(Conn<S, CopyIn, C>, CopyResponse)
The command entered COPY IN.
CopyOut(Conn<S, CopyOut, C>, CopyResponse)
The command entered COPY OUT.
CopyBoth(Conn<S, CopyBoth, C>, CopyResponse)
The command entered COPY BOTH.
Ready(ReadyState<S, C>)
Readiness completed the simple-query cycle.
Error(Conn<S, Draining, C>, ErrorResponse)
An error entered drain-until-ready recovery.