Intermediary

Struct Intermediary 

pub struct Intermediary<Server = (), Client = (), Resolver = (), Route = AllowAuthenticatedRoute, Policy = NoPipeline, Boundary = IdentityIntermediaryMiddleware, Cancellation = RejectCancellation> { /* private fields */ }
A reusable operational intermediary configuration.

Implementations

Source

impl Intermediary<()>

pub fn builder() -> IntermediaryBuilder

Starts composition of the two complete role configurations.

Source

impl<ST, SA, SM, Connector, CT, CA, CM, Resolver, Route, Policy, Boundary, K> Intermediary<Server<ST, SA, SM>, Client<Connector, CT, CA, CM>, Resolver, Route, Policy, Boundary, K>

pub async fn accept<DT, State, Peer, CW, UT, CE>( &self, transport: DT, peer: Peer, state: State, ) -> Result<IntermediaryAccept<IntermediaryConnection<DT, UT, State, Peer, <SA::Authentication as ServerAuthentication<Peer>>::Identity, CA::Evidence, <SM as MiddlewareFactory<ServerConnectionContext<Peer, <SA::Authentication as ServerAuthentication<Peer>>::Identity>>>::Handler, <CM as MiddlewareFactory<ClientInitialContext>>::Handler, <Boundary as IntermediaryMiddlewareFactory<ServerConnectionContext<Peer, <SA::Authentication as ServerAuthentication<Peer>>::Identity>, ClientConnectionContext<CA::Evidence>>>::Handler, Policy, K>>, IntermediaryAcceptError<AcceptError<<ST::Provider as ServerIdentityProvider>::Error, <SA::Authentication as ServerAuthentication<Peer>>::Error>, Resolver::Error, Route::Error, ConnectError<CE, ClientTlsError<<CT::Provider as ClientTlsProvider>::Error>, ClientAuthenticationError<CA::Error>>, K::Error, CancelError<CE>>>

Establishes both independently authenticated roles around one shared state.

Errors

Returns the typed failure from either role or routing policy, or explicit cancellation rejection.