ServerBuilder

Struct ServerBuilder 

pub struct ServerBuilder<Tls = (), Authentication = (), Middleware = IdentityServerHandler> { /* private fields */ }
Builder for a reusable Server.

Implementations

Source

impl<Tls, Authentication, Middleware> ServerBuilder<Tls, Authentication, Middleware>

pub fn tls<Next>( self, policy: Next, ) -> ServerBuilder<Next, Authentication, Middleware>

Selects the client-facing TLS posture explicitly.

pub fn authentication<Next>( self, policy: Next, ) -> ServerBuilder<Tls, Next, Middleware>

Replaces the authentication policy used for each accepted connection.

pub fn limits(self, limits: ServerProtocolLimits) -> Self

Replaces the conservative protocol limits.

pub fn middleware<Next>( self, factory: Next, ) -> ServerBuilder<Tls, Authentication, MiddlewareChain<Middleware, Next>>

Appends a synchronous, infallible per-connection middleware factory.

pub fn build( self, ) -> Result<Server<Tls, Authentication, Middleware>, BuildServerError>

Validates configuration and creates an immutable reusable component.

Errors

Returns an error when either security policy is omitted or a protocol limit cannot be represented by the PostgreSQL wire format.