TypedSession

Struct TypedSession 

pub struct TypedSession<Transport, Phase, Cleanliness = ()> { /* private fields */ }
Transport-carrying typestate for this protocol role.

Implementations

Source

impl<Transport, Cleanliness> TypedSession<Transport, Auth, Cleanliness>

pub const fn with_transport(transport: Transport) -> Self

Attaches transport to a session in the initial phase.

Source

impl<Transport, Phase, Cleanliness> TypedSession<Transport, Phase, Cleanliness>

pub fn map_transport<Next>( self, map: impl FnOnce(Transport) -> Next, ) -> TypedSession<Next, Phase, Cleanliness>

Replaces the transport representation without changing protocol indices.

pub fn into_transport(self) -> Transport

Deliberately leaves the generated typestate API and returns its transport.

Source

impl<Transport, Cleanliness> TypedSession<Transport, Auth, Cleanliness>

pub fn negotiate<Output, Error>( self, payload: NegotiateProtocolVersion, handle: impl FnOnce(&mut Transport, NegotiateProtocolVersion) -> Result<Output, Error>, ) -> Result<(TypedSession<Transport, Auth, Cleanliness>, Output), (Self, Error)>

Handles the payload for negotiate; success enters Auth and failure returns the unchanged session.

pub fn ok(self) -> TypedSession<Transport, AwaitingStartupReady, Cleanliness>

Applies ok and enters AwaitingStartupReady.

pub fn cleartext(self) -> TypedSession<Transport, PasswordResponse, Cleanliness>

Applies cleartext and enters PasswordResponse.

pub fn md5<Output, Error>( self, payload: [u8; 4], handle: impl FnOnce(&mut Transport, [u8; 4]) -> Result<Output, Error>, ) -> Result<(TypedSession<Transport, PasswordResponse, Cleanliness>, Output), (Self, Error)>

Handles the payload for md5; success enters PasswordResponse and failure returns the unchanged session.

pub fn sasl<Output, Error>( self, payload: Vec<Bytes>, handle: impl FnOnce(&mut Transport, Vec<Bytes>) -> Result<Output, Error>, ) -> Result<(TypedSession<Transport, SaslInitial, Cleanliness>, Output), (Self, Error)>

Handles the payload for sasl; success enters SaslInitial and failure returns the unchanged session.

pub fn gss(self) -> TypedSession<Transport, TokenResponse, Cleanliness>

Applies gss and enters TokenResponse.

pub fn sspi(self) -> TypedSession<Transport, TokenResponse, Cleanliness>

Applies sspi and enters TokenResponse.

pub fn kerberos_v5(self) -> TypedSession<Transport, TokenResponse, Cleanliness>

Applies kerberos_v5 and enters TokenResponse.

pub fn error<Output, Error>( self, payload: DiagnosticResponse, handle: impl FnOnce(&mut Transport, DiagnosticResponse) -> Result<Output, Error>, ) -> Result<(TypedSession<Transport, Terminated, Cleanliness>, Output), (Self, Error)>

Handles the payload for error; success enters Terminated and failure returns the unchanged session.

Source

impl<Transport, Cleanliness> TypedSession<Transport, PasswordResponse, Cleanliness>

pub fn password<Output, Error>( self, payload: Bytes, handle: impl FnOnce(&mut Transport, Bytes) -> Result<Output, Error>, ) -> Result<(TypedSession<Transport, AwaitingAuthOk, Cleanliness>, Output), (Self, Error)>

Handles the payload for password; success enters AwaitingAuthOk and failure returns the unchanged session.

Source

impl<Transport, Cleanliness> TypedSession<Transport, TokenResponse, Cleanliness>

pub fn response<Output, Error>( self, payload: Bytes, handle: impl FnOnce(&mut Transport, Bytes) -> Result<Output, Error>, ) -> Result<(TypedSession<Transport, TokenChallenge, Cleanliness>, Output), (Self, Error)>

Handles the payload for response; success enters TokenChallenge and failure returns the unchanged session.

Source

impl<Transport, Cleanliness> TypedSession<Transport, TokenChallenge, Cleanliness>

pub fn continue_token<Output, Error>( self, payload: Bytes, handle: impl FnOnce(&mut Transport, Bytes) -> Result<Output, Error>, ) -> Result<(TypedSession<Transport, TokenResponse, Cleanliness>, Output), (Self, Error)>

Handles the payload for continue_token; success enters TokenResponse and failure returns the unchanged session.

pub fn ok(self) -> TypedSession<Transport, AwaitingStartupReady, Cleanliness>

Applies ok and enters AwaitingStartupReady.

pub fn error<Output, Error>( self, payload: DiagnosticResponse, handle: impl FnOnce(&mut Transport, DiagnosticResponse) -> Result<Output, Error>, ) -> Result<(TypedSession<Transport, Terminated, Cleanliness>, Output), (Self, Error)>

Handles the payload for error; success enters Terminated and failure returns the unchanged session.

Source

impl<Transport, Cleanliness> TypedSession<Transport, SaslInitial, Cleanliness>

pub fn initial<Output, Error>( self, payload: SaslInitialResponse, handle: impl FnOnce(&mut Transport, SaslInitialResponse) -> Result<Output, Error>, ) -> Result<(TypedSession<Transport, Sasl, Cleanliness>, Output), (Self, Error)>

Handles the payload for initial; success enters Sasl and failure returns the unchanged session.

Source

impl<Transport, Cleanliness> TypedSession<Transport, Sasl, Cleanliness>

pub fn continue_response<Output, Error>( self, payload: Bytes, handle: impl FnOnce(&mut Transport, Bytes) -> Result<Output, Error>, ) -> Result<(TypedSession<Transport, SaslChallenge, Cleanliness>, Output), (Self, Error)>

Handles the payload for continue_response; success enters SaslChallenge and failure returns the unchanged session.

pub fn final_response<Output, Error>( self, payload: Bytes, handle: impl FnOnce(&mut Transport, Bytes) -> Result<Output, Error>, ) -> Result<(TypedSession<Transport, SaslFinal, Cleanliness>, Output), (Self, Error)>

Handles the payload for final_response; success enters SaslFinal and failure returns the unchanged session.

pub fn error<Output, Error>( self, payload: DiagnosticResponse, handle: impl FnOnce(&mut Transport, DiagnosticResponse) -> Result<Output, Error>, ) -> Result<(TypedSession<Transport, Terminated, Cleanliness>, Output), (Self, Error)>

Handles the payload for error; success enters Terminated and failure returns the unchanged session.

Source

impl<Transport, Cleanliness> TypedSession<Transport, SaslChallenge, Cleanliness>

pub fn response<Output, Error>( self, payload: Bytes, handle: impl FnOnce(&mut Transport, Bytes) -> Result<Output, Error>, ) -> Result<(TypedSession<Transport, Sasl, Cleanliness>, Output), (Self, Error)>

Handles the payload for response; success enters Sasl and failure returns the unchanged session.

Source

impl<Transport, Cleanliness> TypedSession<Transport, SaslFinal, Cleanliness>

pub fn verified(self) -> TypedSession<Transport, AwaitingAuthOk, Cleanliness>

Applies verified and enters AwaitingAuthOk.

Source

impl<Transport, Cleanliness> TypedSession<Transport, AwaitingAuthOk, Cleanliness>

pub fn ok(self) -> TypedSession<Transport, AwaitingStartupReady, Cleanliness>

Applies ok and enters AwaitingStartupReady.

pub fn error<Output, Error>( self, payload: DiagnosticResponse, handle: impl FnOnce(&mut Transport, DiagnosticResponse) -> Result<Output, Error>, ) -> Result<(TypedSession<Transport, Terminated, Cleanliness>, Output), (Self, Error)>

Handles the payload for error; success enters Terminated and failure returns the unchanged session.

Source

impl<Transport, Cleanliness> TypedSession<Transport, AwaitingStartupReady, Cleanliness>

pub fn ready<Output, Error>( self, payload: TransactionStatus, handle: impl FnOnce(&mut Transport, TransactionStatus) -> Result<Output, Error>, ) -> Result<(TypedSession<Transport, Ready, Cleanliness>, Output), (Self, Error)>

Handles the payload for ready; success enters Ready and failure returns the unchanged session.