pub enum InterceptError<Error, Message> {
Middleware(Error),
Invalid(Message),
}Expand description
Failure while applying or validating middleware output.
Variants
Middleware(Error)
Middleware rejected the message according to its own policy.
Invalid(Message)
Middleware returned a message which is illegal in the supplied state.