pub enum TypedBackendMessage<ProtocolMessage> {
Protocol(ProtocolMessage),
Asynchronous(AsynchronousBackendMessage),
}Expand description
Any server message legal in a phase, including non-advancing asynchronous traffic.
Variants
Protocol(ProtocolMessage)
A message represented by a transition in the current grammar phase.
Asynchronous(AsynchronousBackendMessage)
An asynchronous message which leaves the current grammar phase unchanged.