pub trait ReconstructableMessage {
// Required method
fn is_reconstructable(&self) -> bool;
}Expand description
A protocol message which can verify that it has a valid wire representation.
Required Methods
Sourcefn is_reconstructable(&self) -> bool
fn is_reconstructable(&self) -> bool
Reports whether this typed value can be encoded on the wire.
Dyn Compatibility
This trait is dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".