pub trait TypedOutboundPhase<Role, Wire> {
type ProtocolPhase;
type Message: AsRef<Wire> + TryFrom<Wire, Error = Wire> + Into<Wire>;
}Expand description
Associates a connection typestate with messages its local role may send.
Unlike TypedPhase, which describes peer-selected input, this trait indexes
the generated internal message set used before a locally generated value is
encoded and sent.
Required Associated Types
Sourcetype ProtocolPhase
type ProtocolPhase
Generated grammar phase corresponding to the connection typestate.
Dyn Compatibility
This trait is dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".