Server-role authentication typestates for proxy-side client termination.
Structs
- Sasl
Initial Response - A decoded SASL initial response selected by the client.
Enums
- Server
Auth - The proxy is selecting how to authenticate its client.
- Server
Auth Response - A GSS, SSPI, or Kerberos response token is expected.
- Server
Password - A password response is expected from the client.
- Server
Protocol Offer - Result of validating a client’s requested protocol version.
- Server
Sasl - A recursive SASL response exchange is in progress.
- Server
Sasl Initial - A SASL initial response is expected from the client.
- Server
Startup Ready - Authentication succeeded and startup metadata may be sent before readiness.
- Server
Startup Rejected - The client’s startup protocol version must be rejected.
- Server
Startup Validated - The client’s startup protocol version is supported.
Type Aliases
- Password
Projection - Projection of a valid password body or the unchanged server-password state.
- Sasl
Initial Projection - Projection of a valid SASL initial response or the unchanged initial state.
- Server
Projection - A rejected frontend message paired with the unchanged authentication state.