pub struct ServerBuilder<Tls = (), Authentication = (), Middleware = IdentityServerHandler> { /* private fields */ }Expand description
Builder for a reusable Server.
Implementations
Sourceimpl<Tls, Authentication, Middleware> ServerBuilder<Tls, Authentication, Middleware>
impl<Tls, Authentication, Middleware> ServerBuilder<Tls, Authentication, Middleware>
Sourcepub fn tls<Next>(
self,
policy: Next,
) -> ServerBuilder<Next, Authentication, Middleware>
pub fn tls<Next>( self, policy: Next, ) -> ServerBuilder<Next, Authentication, Middleware>
Selects the client-facing TLS posture explicitly.
Sourcepub fn authentication<Next>(
self,
policy: Next,
) -> ServerBuilder<Tls, Next, Middleware>
pub fn authentication<Next>( self, policy: Next, ) -> ServerBuilder<Tls, Next, Middleware>
Replaces the authentication policy used for each accepted connection.
Sourcepub fn limits(self, limits: ServerProtocolLimits) -> Self
pub fn limits(self, limits: ServerProtocolLimits) -> Self
Replaces the conservative protocol limits.
Sourcepub fn middleware<Next>(
self,
factory: Next,
) -> ServerBuilder<Tls, Authentication, MiddlewareChain<Middleware, Next>>
pub fn middleware<Next>( self, factory: Next, ) -> ServerBuilder<Tls, Authentication, MiddlewareChain<Middleware, Next>>
Appends a synchronous, infallible per-connection middleware factory.
Sourcepub fn build(
self,
) -> Result<Server<Tls, Authentication, Middleware>, BuildServerError>
pub fn build( self, ) -> Result<Server<Tls, Authentication, Middleware>, BuildServerError>
Validates configuration and creates an immutable reusable component.
Errors
Returns an error when either security policy is omitted or a protocol limit cannot be represented by the PostgreSQL wire format.